==> sqlitestudio-3.0.7.tar.gz: Plugins/PdfExport/PdfExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>PdfExport</name>
    <message>
        <location filename="pdfexport.cpp" line="28"/>
        <source>SQLiteStudio v%1</source>
        <translation>SQLiteStudio v%1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="60"/>
        <source>SQL query results</source>
        <translation>Résultats de la requête SQL</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="89"/>
        <location filename="pdfexport.cpp" line="143"/>
        <source>Exported table: %1</source>
        <translation>Table exportée: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="92"/>
        <location filename="pdfexport.cpp" line="158"/>
        <source>Table: %1</source>
        <translation>Table: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="94"/>
        <location filename="pdfexport.cpp" line="230"/>
        <source>Column</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="94"/>
        <source>Data type</source>
        <translation>Type de données</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="94"/>
        <source>Constraints</source>
        <translation>Contraintes</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="125"/>
        <source>Global table constraints</source>
        <translation>Contraintes globales de la table</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="214"/>
        <source>Exported database: %1</source>
        <translation>Base de données exportée: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="222"/>
        <source>Index: %1</source>
        <translation>Index: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="224"/>
        <source>Property</source>
        <comment>index header</comment>
        <translation>Proprièté</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="224"/>
        <source>Value</source>
        <comment>index header</comment>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="227"/>
        <source>Indexed table</source>
        <translation>Table indexées</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="228"/>
        <source>Unique index</source>
        <translation>Index unique</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="228"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="228"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="230"/>
        <source>Collation</source>
        <translation>Collation</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="230"/>
        <source>Sort order</source>
        <translation>Ordre de tri</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="246"/>
        <source>Partial index condition</source>
        <translation>Condition de l&apos;index partiel</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="260"/>
        <source>Trigger: %1</source>
        <translation>Déchencheur: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="262"/>
        <source>Property</source>
        <comment>trigger header</comment>
        <translation>Proprièté</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="262"/>
        <source>Value</source>
        <comment>trigger header</comment>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="264"/>
        <source>Activation time</source>
        <translation>Activation temps</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="267"/>
        <source>For action</source>
        <translation>Pour action</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="271"/>
        <source>On view</source>
        <translation>De la vue</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="273"/>
        <source>On table</source>
        <translation>De la vue</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="278"/>
        <source>Activation condition</source>
        <translation>Activation de la condition</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="284"/>
        <source>Code executed</source>
        <translation>Code exécuté</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="296"/>
        <source>View: %1</source>
        <translation>Vue: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="297"/>
        <source>Query:</source>
        <translation>Requête:</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="649"/>
        <source>Document generated with SQLiteStudio v%1</source>
        <translation>Documentation générée avec SQLiteStudio v%1</translation>
    </message>
</context>
<context>
    <name>PdfExportConfig</name>
    <message>
        <location filename="pdfexport.ui" line="20"/>
        <source>Size and layout</source>
        <translation>Dimension et mise en page</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="36"/>
        <source>Page size:</source>
        <translation>Dimension page:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="63"/>
        <source>Right margin:</source>
        <translation>Marge droite:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="70"/>
        <source>Left margin:</source>
        <translation>Marge gauche:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="77"/>
        <source>Cell padding:</source>
        <translation>Remplissage cellule:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="84"/>
        <source>Limit characters in single cell:</source>
        <translation>Limite de caractères dans une cellule unique:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="91"/>
        <location filename="pdfexport.ui" line="108"/>
        <location filename="pdfexport.ui" line="115"/>
        <location filename="pdfexport.ui" line="132"/>
        <location filename="pdfexport.ui" line="156"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="139"/>
        <source>Bottom margin:</source>
        <translation>Marge inférieure:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="163"/>
        <source>Top margin:</source>
        <translation>Marge supérieure:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="183"/>
        <source>Font</source>
        <translation>Police</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="206"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="212"/>
        <source>Headers background:</source>
        <translation>Arrière plan des en-têtes:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="235"/>
        <source>NULL value color:</source>
        <translation>Couleur pour valeur NULL:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="261"/>
        <source>Other settings</source>
        <translation>Autres paramètres</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="267"/>
        <source>Print row numbers for data</source>
        <translation>Nombre de lignes de données à imprimer</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="277"/>
        <source>Print page numbers</source>
        <translation>Imprimer nombre de pages</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/PdfExport/PdfExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>PdfExport</name>
    <message>
        <location filename="pdfexport.cpp" line="28"/>
        <source>SQLiteStudio v%1</source>
        <translation>SQLiteStudio v%1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="60"/>
        <source>SQL query results</source>
        <translation>Résultats de la requête SQL</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="89"/>
        <location filename="pdfexport.cpp" line="143"/>
        <source>Exported table: %1</source>
        <translation>Table exportée: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="92"/>
        <location filename="pdfexport.cpp" line="158"/>
        <source>Table: %1</source>
        <translation>Table: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="94"/>
        <location filename="pdfexport.cpp" line="230"/>
        <source>Column</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="94"/>
        <source>Data type</source>
        <translation>Type de données</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="94"/>
        <source>Constraints</source>
        <translation>Contraintes</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="125"/>
        <source>Global table constraints</source>
        <translation>Contraintes globales de la table</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="214"/>
        <source>Exported database: %1</source>
        <translation>Base de données exportée: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="222"/>
        <source>Index: %1</source>
        <translation>Index: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="224"/>
        <source>Property</source>
        <comment>index header</comment>
        <translation>Proprièté</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="224"/>
        <source>Value</source>
        <comment>index header</comment>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="227"/>
        <source>Indexed table</source>
        <translation>Table indexées</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="228"/>
        <source>Unique index</source>
        <translation>Index unique</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="228"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="228"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="230"/>
        <source>Collation</source>
        <translation>Collation</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="230"/>
        <source>Sort order</source>
        <translation>Ordre de tri</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="246"/>
        <source>Partial index condition</source>
        <translation>Condition de l&rsquo;index partiel</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="260"/>
        <source>Trigger: %1</source>
        <translation>Déchencheur: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="262"/>
        <source>Property</source>
        <comment>trigger header</comment>
        <translation>Proprièté</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="262"/>
        <source>Value</source>
        <comment>trigger header</comment>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="264"/>
        <source>Activation time</source>
        <translation>Activation temps</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="267"/>
        <source>For action</source>
        <translation>Pour action</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="271"/>
        <source>On view</source>
        <translation>De la vue</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="273"/>
        <source>On table</source>
        <translation>De la vue</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="278"/>
        <source>Activation condition</source>
        <translation>Activation de la condition</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="284"/>
        <source>Code executed</source>
        <translation>Code exécuté</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="296"/>
        <source>View: %1</source>
        <translation>Vue: %1</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="297"/>
        <source>Query:</source>
        <translation>Requête:</translation>
    </message>
    <message>
        <location filename="pdfexport.cpp" line="649"/>
        <source>Document generated with SQLiteStudio v%1</source>
        <translation>Documentation générée avec SQLiteStudio v%1</translation>
    </message>
</context>
<context>
    <name>PdfExportConfig</name>
    <message>
        <location filename="pdfexport.ui" line="20"/>
        <source>Size and layout</source>
        <translation>Dimension et mise en page</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="36"/>
        <source>Page size:</source>
        <translation>Dimension page:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="63"/>
        <source>Right margin:</source>
        <translation>Marge droite:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="70"/>
        <source>Left margin:</source>
        <translation>Marge gauche:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="77"/>
        <source>Cell padding:</source>
        <translation>Remplissage cellule:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="84"/>
        <source>Limit characters in single cell:</source>
        <translation>Limite de caractères dans une cellule unique:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="91"/>
        <location filename="pdfexport.ui" line="108"/>
        <location filename="pdfexport.ui" line="115"/>
        <location filename="pdfexport.ui" line="132"/>
        <location filename="pdfexport.ui" line="156"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="139"/>
        <source>Bottom margin:</source>
        <translation>Marge inférieure:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="163"/>
        <source>Top margin:</source>
        <translation>Marge supérieure:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="183"/>
        <source>Font</source>
        <translation>Police</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="206"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="212"/>
        <source>Headers background:</source>
        <translation>Arrière plan des en-têtes:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="235"/>
        <source>NULL value color:</source>
        <translation>Couleur pour valeur NULL:</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="261"/>
        <source>Other settings</source>
        <translation>Autres paramètres</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="267"/>
        <source>Print row numbers for data</source>
        <translation>Nombre de lignes de données à imprimer</translation>
    </message>
    <message>
        <location filename="pdfexport.ui" line="277"/>
        <source>Print page numbers</source>
        <translation>Imprimer nombre de pages</translation>
    </message>
</context>
</TS>
